pub fn validate_project_path(name: &str) -> Result<()>
Validate that a path does not escape the current working directory.
Used for zernel init to prevent creating projects in arbitrary locations.
zernel init